<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'Ŝirmilo por la forumoj kontraŭ transreteja atakoj',
	'safehtml_slogan' => 'Ŝirmilo por la forumoj kontraŭ transreteja atakoj',
];
